# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the Custom Service Manager."""

__version__ = "1.20.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .bulk_save_subscription__e5ef74 import BulkSaveSubscriptionAppNotificationV2
from .delete_subscription_app_0003d9 import DeleteSubscriptionAppNotificationByUserIDV2
from .delete_subscription_app_84e329 import DeleteSubscriptionAppNotificationV2
from .get_notification_subscr_4bced3 import GetNotificationSubscriberListV2
from .get_subscription_v2_handler import GetSubscriptionV2Handler
from .subscribe_app_notification_v2 import SubscribeAppNotificationV2
from .subscribe_v2_handler import SubscribeV2Handler
from .unsubscribe_v2_handler import UnsubscribeV2Handler
