# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the Custom Service Manager."""

__version__ = "1.20.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_deployment_v2 import CreateDeploymentV2
from .delete_deployment_v2 import DeleteDeploymentV2
from .get_deployment_v2 import GetDeploymentV2
from .get_list_of_deployment_v2 import GetListOfDeploymentV2
