# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the Custom Service Manager."""

__version__ = "1.20.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_app_v2 import CreateAppV2
from .delete_app_v2 import DeleteAppV2
from .get_app_list_v2 import GetAppListV2
from .get_app_v2 import GetAppV2
from .start_app_v2 import StartAppV2
from .stop_app_v2 import StopAppV2
from .update_app_resources_re_e22dc4 import UpdateAppResourcesResourceLimitFormV2
from .update_app_resources_v2 import UpdateAppResourcesV2
from .update_app_v2 import UpdateAppV2
